==> haskell-servant-server-0.17-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-server
version:              0.17
visibility:           public
id:                   servant-server-0.17-LJuhaiJHp93EjxLuvsxrUR
key:                  servant-server-0.17-LJuhaiJHp93EjxLuvsxrUR
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    A family of combinators for defining webservices APIs and serving them

description:
    A family of combinators for defining webservices APIs and serving them

    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.

    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.

    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  44aadb2f82709971c8af9e845d8a10b3
exposed:              True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.Handler Servant.Server.Internal.RouteResult
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Utils.StaticFiles

import-dirs:          /usr/lib/ghc-8.10.1/site-local/servant-server-0.17
library-dirs:         /usr/lib/ghc-8.10.1/site-local/servant-server-0.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/servant-server-0.17
hs-libraries:         HSservant-server-0.17-LJuhaiJHp93EjxLuvsxrUR
depends:
    base-4.14.0.0 base-compat-0.11.1-KZnxD44j0rC2RthL96Vmwl
    base64-bytestring-1.1.0.0-4PKusBulJKl5JuJVlDvtDW
    bytestring-0.10.10.0 containers-0.6.2.1 exceptions-0.10.4
    filepath-1.4.2.1 http-api-data-0.4.1.1-AR5IrB8LBzD3YDvkxLTr3Z
    http-media-0.8.0.0-3DSrkGqUJCUIZmZb8T7qEp
    http-types-0.12.3-53LE6EPnjaYL88m7GHuG2H
    monad-control-1.0.2.3-Zolpha2nzyCWjP4MLl5a6 mtl-2.2.2
    network-3.1.1.1-CK9iofx0d8BBZLerEfDW1e
    network-uri-2.6.3.0-CWpK8ej5SnOAz8dByfK7af
    resourcet-1.2.4.1-BfFxYNA42v4HhhW9DWi0Jk
    servant-0.17-8RSR43KdHH915mrmgNhcIz
    string-conversions-0.4.0.1-B7nbcmmSZDsLQwPoMWPWXw
    tagged-0.8.6-6GC8EUw1ctH7ZAzzvpqZ7j text-1.2.3.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-xMHQBtL7qH3C2eAD9DGp5
    wai-3.2.2.1-L6kffhlW6gTELvarEJHibT
    wai-app-static-3.1.7.1-EBv8y2o1PYxAIyMHJhaSds
    word8-0.1.3-2HAv1NwMSKOALyj2PF53yL

haddock-interfaces:
    /usr/share/doc/haskell-servant-server/html/servant-server.haddock

haddock-html:         /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-server-0.17-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-server
version:              0.17
visibility:           public
id:                   servant-server-0.17-3xhfQt4rzxKCN0yLBUBVCZ
key:                  servant-server-0.17-3xhfQt4rzxKCN0yLBUBVCZ
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    A family of combinators for defining webservices APIs and serving them

description:
    A family of combinators for defining webservices APIs and serving them

    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.

    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.

    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  5c8bcdd16bebf159da8f7fd2ee1c37f4
exposed:              True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.Handler Servant.Server.Internal.RouteResult
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Utils.StaticFiles

import-dirs:          /usr/lib/ghc-8.10.1/site-local/servant-server-0.17
library-dirs:         /usr/lib/ghc-8.10.1/site-local/servant-server-0.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/servant-server-0.17
hs-libraries:         HSservant-server-0.17-3xhfQt4rzxKCN0yLBUBVCZ
depends:
    base-4.14.0.0 base-compat-0.11.1-KZnxD44j0rC2RthL96Vmwl
    base64-bytestring-1.1.0.0-4PKusBulJKl5JuJVlDvtDW
    bytestring-0.10.10.0 containers-0.6.2.1 exceptions-0.10.4
    filepath-1.4.2.1 http-api-data-0.4.1.1-AR5IrB8LBzD3YDvkxLTr3Z
    http-media-0.8.0.0-3DSrkGqUJCUIZmZb8T7qEp
    http-types-0.12.3-53LE6EPnjaYL88m7GHuG2H
    monad-control-1.0.2.3-Zolpha2nzyCWjP4MLl5a6 mtl-2.2.2
    network-3.1.1.1-CK9iofx0d8BBZLerEfDW1e
    network-uri-2.6.3.0-JUBVkW8Hh8TLMomDv6Wk2p
    resourcet-1.2.4.1-BfFxYNA42v4HhhW9DWi0Jk
    servant-0.17-1fKIvNfk6oD1Fwht1UoNdm
    string-conversions-0.4.0.1-B7nbcmmSZDsLQwPoMWPWXw
    tagged-0.8.6-6GC8EUw1ctH7ZAzzvpqZ7j text-1.2.3.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-xMHQBtL7qH3C2eAD9DGp5
    wai-3.2.2.1-L6kffhlW6gTELvarEJHibT
    wai-app-static-3.1.7.1-8wV1jULRqliHBTXhaoJlo9
    word8-0.1.3-2HAv1NwMSKOALyj2PF53yL

haddock-interfaces:
    /usr/share/doc/haskell-servant-server/html/servant-server.haddock

haddock-html:         /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
